using System;
using System.Net;
using System.IO;

namespace gethttp
{
	/// <summary>
	/// Program to retrieve a file using http protocol, given a URL
	/// and a file name to store it into.
	/// </summary>
	class gethttp
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			if (args.Length == 2)  // Download a file
			{
				using (System.Net.WebClient web = new System.Net.WebClient())
				{
					try
					{
						web.DownloadFile(args[0],args[1]);
					}
					catch (Exception e)
					{
						Console.WriteLine("Error: {0}",e.Message);
					}
				}
			}
			else if (args.Length == 1) // Write a file to console output
			{
				using (System.Net.WebClient web = new System.Net.WebClient())
				{
					try
					{
						StreamReader infile = new StreamReader(web.OpenRead(args[0]));
						Console.WriteLine(infile.ReadToEnd());
					}
					catch (Exception e)
					{
						Console.WriteLine("Error: {0}",e.Message);
					}
				}
			}
			else
			{
				Console.WriteLine("gethttp - M. Covington 2005\n\n"+
					"Usage:\n\n"+
					"          gethttp  url  filename\n\n"+
					"Retrieves the file at the given url and stores it locally in filename.\n" +
					"If filename is omitted, file is written to standard output.\n\n" +
					"Example:\n\n"+
					"          gethttp http://www.foo.com/data.txt c:\\temp\\data.txt\n\n"
					);
			}
		}
	}
}
